@@ -12,37 +12,39 @@ from .database import (
     non_indexed_foreign_keys,
 )
 from .orm import (
-    primary_keys,
-    table_name,
     declarative_base,
+    getdotattr,
     has_changes,
     identity,
     naturally_equivalent,
-    remove_property
+    primary_keys,
+    remove_property,
+    table_name,
 )
 
 __all__ = (
-    create_mock_engine,
-    defer_except,
-    mock_engine,
-    sort_query,
-    render_expression,
-    render_statement,
-    QuerySorterException,
-    database_exists,
     create_database,
+    create_mock_engine,
+    database_exists,
+    declarative_base,
+    defer_except,
     drop_database,
     escape_like,
-    is_auto_assigned_date_column,
-    is_indexed_foreign_key,
-    non_indexed_foreign_keys,
-    remove_property,
-    primary_keys,
-    table_name,
-    declarative_base,
+    getdotattr,
     has_changes,
     identity,
+    is_auto_assigned_date_column,
+    is_indexed_foreign_key,
+    mock_engine,
     naturally_equivalent,
+    non_indexed_foreign_keys,
+    primary_keys,
+    QuerySorterException,
+    remove_property,
+    render_expression,
+    render_statement,
+    sort_query,
+    table_name,
 )
 
 
